Package: periscope
Type: Package
Title: Enterprise Streamlined 'Shiny' Application Framework
Version: 1.0.4
Authors@R: c(
    person("Constance", "Brett", email="connie@aggregate-genius.com", role = c("aut", "cre")),
    person("Isaac", "Neuhaus", role = "aut", comment = "canvasXpress JavaScript Library Maintainer"),
    person("Ger", "Inberg", role = c("ctb")),
    person("Mohammed", "Ali", role = c("ctb")),
    person("Bristol-Meyers Squibb (BMS)", role = c("cph"))
    )
Description: An enterprise-targeted scalable and UI-standardized 'shiny' framework 
    including a variety of developer convenience functions with the goal of both 
    streamlining robust application development while assisting with creating a 
    consistent user experience regardless of application or developer.
URL: https://github.com/cb4ds/periscope, http://periscopeapps.org:3838
BugReports: https://github.com/cb4ds/periscope/issues
License: GPL-3
Encoding: UTF-8
Language: en-US
Depends: R (>= 3.5)
Imports: shiny (>= 1.5), shinydashboard (>= 0.5), shinyBS (>= 0.61),
        lubridate (>= 1.6), DT (>= 0.2), writexl (>= 1.3), ggplot2 (>=
        2.2), methods, utils, fresh, yaml, grDevices
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown, shinydashboardPlus, testthat (>= 3.0),
        canvasXpress, openxlsx (>= 3.0), colourpicker
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-11-06 19:35:55 UTC; conniebrett
Author: Constance Brett [aut, cre],
  Isaac Neuhaus [aut] (canvasXpress JavaScript Library Maintainer),
  Ger Inberg [ctb],
  Mohammed Ali [ctb],
  Bristol-Meyers Squibb (BMS) [cph]
Maintainer: Constance Brett <connie@aggregate-genius.com>
Repository: CRAN
Date/Publication: 2023-11-06 19:50:02 UTC
Built: R 4.6.0; ; 2026-04-29 23:49:39 UTC; unix
