

This archive contains the distribution Periscope,
version 0.0.3:

  Module for viewing sites through a periscope

This software is copyright (c) 2011 by Delon Newman.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.


