# -------------------------------------------------
# --              FRAMEWORK server.R             --
# -------------------------------------------------
# NOTEs:                                         --
# Program code goes in "program" directory files --
# -------------------------------------------------
# *****        DO NOT EDIT THIS FILE       ***** --
# -------------------------------------------------

source(paste("program", "server_global.R", sep = .Platform$file.sep),
       local = TRUE)


shinyServer(function(input, output, session) {
    ss_userAction.Log     <- periscope:::fw_get_user_log()

    source(paste("program", "server_local.R", sep = .Platform$file.sep),
           local = TRUE)

    periscope:::fw_server_setup(input, output, session, ss_userAction.Log)

    loginfo("%s started with log level <%s>",
            periscope:::fw_get_title(), periscope:::fw_get_loglevel(),
            logger = ss_userAction.Log)
})
