# -------------------------------------------------
# --               FRAMEWORK ui.R                --
# -------------------------------------------------
# NOTEs:                                         --
# Program code goes in "program" directory files --
# -------------------------------------------------
# *****        DO NOT EDIT THIS FILE       ***** --
# -------------------------------------------------

library(shinydashboard)

periscope:::fw_reset_app_options()

source(paste("program", "ui_sidebar.R", sep = .Platform$file.sep),
       local = TRUE)
source(paste("program", "ui_body.R", sep = .Platform$file.sep),
       local = TRUE)


dashboardPage(periscope:::fw_create_header(),
              periscope:::fw_create_sidebar(),
              periscope:::fw_create_body())
