# -------------------------------------------------
# --               FRAMEWORK ui.R                --
# -------------------------------------------------
# NOTEs:                                         --
# Program code goes in "program" directory files --
# -------------------------------------------------
# *****       DO NOT EDIT THIS FILE        ***** --
# -------------------------------------------------

library(shinydashboardPlus)

periscope:::fw_reset_app_options()

source(paste("program", "ui_sidebar.R", sep = .Platform$file.sep),
       local = TRUE)
source(paste("program", "ui_sidebar_right.R", sep = .Platform$file.sep),
       local = TRUE)
source(paste("program", "ui_body.R", sep = .Platform$file.sep),
       local = TRUE)


addl_opts <- list()
if (utils::packageVersion('shinydashboardPlus') < "2") {
    plus_fxn  <- getExportedValue("shinydashboardPlus", "dashboardPagePlus")
    addl_opts <- list(sidebar_fullCollapse = TRUE)
} else {
    plus_fxn <- getExportedValue("shinydashboardPlus", "dashboardPage")
}

do.call(plus_fxn, c(list(periscope:::fw_create_header_plus(),
                         periscope:::fw_create_sidebar(),
                         periscope:::fw_create_body(),
                         periscope:::fw_create_right_sidebar()),
                    addl_opts))
